function [data,unit]=mphevalglobalmatrix(model,expr,varargin)
% MPHEVALGLOBALMATRIX Evaluate global matrix variables
%
%   [M,UNIT] = MPHEVALGLOBALMATRIX(MODEL, EXPR, ...) evaluates the 
%   global matrix of the variable EXPR and returns the full matrix M and 
%   unit in UNIT.
%
%   This is useful for extracting a capacitance matrix or a S-parameters 
%   matrix from a model.
%
%   Valid property/value pairs include:
%   Property        Value/{Default}            Description
%   -----------------------------------------------------------------------
%   dataset         String {''}                Data set tag
%   dataseries      {'none'} | 'average' |     Data series operation
%                   'sum'
%   outerdataseries {'none'} | 'average' |     Outer data series operation
%                   'sum'
%   outersolnum     Integer vector {1} |       Solution number for 
%                   'first' | 'last' | 'all'   parametric sweep
%   solnum          Integer vector |           Solution for evaluation
%                   'end' | {'all'}
%   t               Double array {''}          Time for evaluation
%   trans           {None} | inverse | sy |    Matrix transformation
%                   sz | ys | yz | zs | zy |
%                   maxwellmutual | 
%                   mutualmaxwell | 
%                   invmaxwellmutual
%   unit            String {''}                Unit to use for the evaluation
%   y0              Double array               If Trans is sy or ys: the
%                                              characteristic admittance
%   z0              Double array               If Trans is sz or zs: the
%                                              characteristic impedance
%
%   Note: S-parameter evaluation requires the RF Module.
%
%   Example:
%     % Load h_bend_waveguide_2d.mph from the RF Module's Model library
%     model = mphopen('h_bend_waveguide_2d');
%     % Evaluate the S-parameters matrix using the solution data set dset2:  
%     M = mphevalglobalmatrix(model, 'emw.SdB', 'dataset', 'dset2')
%
%   See also: mpheval, mphevalpoint, mphevalpointmatrix, mphglobal, mphint2, 
%   mphinterp

%   Copyright 2012-2023 COMSOL
